/* vim: set noet ts=4:
 *
 * Copyright (c) 2002-2007 Martin A. Godisch <martin@godisch.de>.
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
 * St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
#ifndef _LATRINE_H
#define _LATRINE_H

#include <assert.h>
#include <config.h>
#include <stdio.h>

#include <libintl.h>
#define _(string) gettext(string)

#define MODE_NORMAL  1
#define MODE_REVERSE 2
#define MODE_MIXED   3

#include <errno.h>
#include <string.h>
extern FILE *debug;
extern void errmsg(const char*, ...);

#endif
